/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */


package sync4j.framework.core;

/**
 * Corresponds to the &lt;Exec&gt; tag in the SyncML represent DTD
 *
 * @author Stefano Fonari @ Funambol
 *
 * @version $Id: Exec.java,v 1.5 2006/02/07 09:56:56 luigiafassina Exp $
 */
public final class Exec
extends ModificationCommand
implements java.io.Serializable {
    
    // --------------------------------------------------------------- Constants
    public static String COMMAND_NAME = "Exec";
    
    // ------------------------------------------------------------ Constructors    
    /** For serialization purposes */
    protected Exec() {}
    
    /** 
     * Creates a new Exec object with the given command identifier, 
     * noResponse, credential and item
     *
     * @param cmdID the command identifier - NOT NULL
     * @param noResp true if no response is required
     * @param cred the authentication credential
     * @param item the item - NOT NULL
     *
     */
    public Exec(final CmdID cmdID,
                final boolean noResp,
                final Cred cred,
                final Item item) {
        super(cmdID, new Item[] { item });
        
        this.noResp  = (noResp) ? new Boolean(noResp) : null;
        setCred(cred);
    }

    // ---------------------------------------------------------- Public methods
    /**
     * Gets the command name property
     *
     * @return the command name property
     */   
    public String getName() {
        return Exec.COMMAND_NAME;
    }
    
    /**
     * Gets an Item object
     *
     * @return an Item object
     */    
    public Item getItem() {
        return (Item)items.get(0);
    }
}
