/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */



package sync4j.framework.logging;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.text.MessageFormat;
import java.util.Date;
import java.util.logging.Formatter;
import java.util.logging.Level;
import java.util.logging.LogRecord;

/**
 * This is a very basic logger that traces only <i>level, timestamp and message</i>.
 * The use of this logger has two advantages:
 * <ul>
 *  <li>it is less verbose (it does not display class and method name)</li>
 *  <li>it is quicker (it does not look into the stack trace in order to 
 *      infer class and method name</li>
 * </ul>
 *
 * @author Stefano Fornari @ Funambol
 *
 * @version $Id: SimpleFormatter.java,v 1.4 2006/02/07 09:56:56 luigiafassina Exp $
 */

public class SimpleFormatter extends Formatter {
    
    // --------------------------------------------------------------- Constants
   
    private final static String FORMAT = "[{0,date} {0,time}]";
    private final static String NL = System.getProperty("line.separator");
    
    // ---------------------------------------------------------- Private fields
    
    private MessageFormat formatter;
    
    // ---------------------------------------------------------- Public methids

    /**
     * Format the given LogRecord.
     *
     * @param record the log record to be formatted.
     *
     * @return a formatted log record as String
     */
    public synchronized String format(LogRecord record) {
        Object args[] = new Object[1];
        
        StringBuffer sb = new StringBuffer();
        
        Date d = new Date();
        
        // Minimize memory allocations here.
        d.setTime(record.getMillis());
        args[0] = d;

        if (formatter == null) {
            formatter = new MessageFormat(FORMAT);
        }
        formatter.format(args, sb, null);
        //
        // Show the loggger name only if the level of the record is more 
        // detailed then INFO
        //
        if (record.getLevel().intValue() != Level.INFO.intValue()) {
            sb.append('[').append(record.getLoggerName()).append(']');
        }
        sb.append(' ');
        sb.append(record.getLevel().getName());
        sb.append(": ");
        sb.append(formatMessage(record));
        sb.append(NL);
        
    	if (record.getThrown() != null) {
            StringWriter sw = new StringWriter(  );
            PrintWriter  pw = new PrintWriter (sw);
            try {
                record.getThrown().printStackTrace(pw);
                sb.append(sw.toString());
                sb.append(NL);
            } catch (Exception ex) {
                //
                // What to do here???
                //
            } finally {
                try { pw.close(); } catch (Exception e) {}
            }
        }
        
        return sb.toString();
    }
}
