/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */


package sync4j.server.syncbean;

import java.util.Map;

import javax.ejb.*;

import sync4j.framework.server.SyncResponse;
import sync4j.framework.server.error.ServerException;

/**
  *
  * @author Stefano Fornari
  * @version $Id: SyncLocal.java,v 1.11 2006/02/07 09:56:58 luigiafassina Exp $
  */
public interface SyncLocal extends EJBLocalObject {
    
    /** Processes an incoming XML message.
     *
     * @param requestData the SyncML request as stream of bytes
     * @param parameters SyncML request parameters
     * @param headers SyncML request headers
     *
     * @return the SyncML response as a <i>ISyncResponse</i> object
     *
     * @throws ServerException in case of a server error
     *
     */
    public SyncResponse processXMLMessage(final byte[] requestData, 
                                          final Map    parameters , 
                                          final Map    headers    ) throws ServerException;
    
    /** Processes an incoming WBXML message.
     *
     * @param requestData the SyncML request as stream of bytes
     * @param parameters SyncML request parameters
     * @param headers SyncML request headers
     *
     * @return the SyncML response as a <i>ISyncResponse</i> object
     *
     * @throws ServerException in case of a server error
     *
     */
    public SyncResponse processWBXMLMessage(final byte[] requestData, 
                                            final Map    parameters , 
                                            final Map    headers    ) throws ServerException;
    
    
    
    /**
     * Used to process a status information as needed by the client object (i.e.
     * errors or success).
     *
     * @param statusCode the status code
     * @param info additional informational message
     *
     * @return the response message
     *
     * @see sync4j.framework.core.StatusCode for valid status codes.
     */
    public SyncResponse processStatusCode(int statusCode, String info);
}

