--
-- This script contains the ddl to create the engine database.
--
-- @version $Id: create_engine.ddl,v 1.23 2005/10/26 10:41:17 luigiafassina Exp $
--

create table sync4j_principal
(
  username    varchar(32) not null,
  device      varchar(128) not null,
  id          integer      not null,
  
  constraint pk_sync4j_principal primary key (id)
);

create table sync4j_user
(
  username   varchar(32) not null,
  password   varchar(32) not null,
  email      varchar(50),
  first_name varchar(255),
  last_name  varchar(255),
    
  constraint pk_sync4j_user primary key (username)
);


CREATE TABLE sync4j_device
(
  id              VARCHAR(128) NOT NULL,
  description     VARCHAR(255),
  type            VARCHAR(255),
  client_nonce    VARCHAR(255),
  server_nonce    VARCHAR(255),
  server_password VARCHAR(255),
  id_caps         INTEGER NOT NULL default '2',
  timezone        VARCHAR(50),  
  convert_date    CHAR(1),  
  charset         VARCHAR(50),    
  
  CONSTRAINT pk_sync4j_device PRIMARY KEY (id)
);

create table sync4j_device_caps
(
  id              INTEGER not null,
  largeobject     CHAR(1) not null default 'N',
  numberofchanges CHAR(1) not null default 'N',
  
  constraint pk_sync4j_device_caps primary key (id)
);

create table sync4j_sync_source
(
  uri    varchar(128) not null,
  config varchar(255) not null,
  name         varchar(200) not null,
  sourcetype   varchar(128) not null,

  
  constraint pk_sync4j_sync_source primary key (uri)
);



create table sync4j_last_sync
(
  principal   integer not null,
  sync_source        varchar(128) not null,
  last_anchor_server varchar(20 ),
  last_anchor_client varchar(20 ),
  start_sync         datetime,
  end_sync           datetime,
  
  constraint pk_sync4j_last_sync primary key (principal, sync_source)
);



create table sync4j_client_mapping
(
  principal   integer not null,
  sync_source varchar(128) not null,
  luid        varchar(200) not null,
  guid        varchar(200) not null,
  
  constraint pk_clientmapping primary key (principal, sync_source, luid, guid)
);



CREATE TABLE sync4j_id
(
  idspace VARCHAR(30) NOT NULL,
  counter integer     NOT NULL,
  
  CONSTRAINT pk_sync4j_id PRIMARY KEY (idspace)
);


CREATE TABLE sync4j_module
(
  id          VARCHAR(128) NOT NULL,
  name        VARCHAR(200) NOT NULL,
  description VARCHAR(200),
  
  CONSTRAINT pk_sync4j_module PRIMARY KEY (id)
);


CREATE TABLE sync4j_sync_source_type
(
  id           VARCHAR(128) NOT NULL,
  description  VARCHAR(200),
  class        VARCHAR(255) NOT NULL,
  admin_class  VARCHAR(255),
  
  CONSTRAINT pk_sync4j_sst PRIMARY KEY (id)
);


CREATE TABLE sync4j_module_sync_source_type
(
  module     VARCHAR(128) NOT NULL,
  sourcetype VARCHAR(128) NOT NULL,
  
  CONSTRAINT pk_sync4j_msst PRIMARY KEY (module, sourcetype)
);



CREATE TABLE sync4j_connector
(
  id            VARCHAR(128) NOT NULL,
  name          VARCHAR(200) NOT NULL,
  description   VARCHAR(200),
  admin_class   VARCHAR(255),
    
  CONSTRAINT pk_sync4j_connector PRIMARY KEY (id)
);


CREATE TABLE sync4j_module_connector
(
  module      VARCHAR(128) NOT NULL,
  connector   VARCHAR(128) NOT NULL,
    
  CONSTRAINT pk_sync4j_module_connector PRIMARY KEY (module, connector)
);


CREATE TABLE sync4j_connector_source_type
(
  connector  VARCHAR(128) NOT NULL,
  sourcetype VARCHAR(128) NOT NULL,
  
  CONSTRAINT pk_sync4j_connector_sst PRIMARY KEY (connector, sourcetype)
);


CREATE TABLE sync4j_role
(
  role        VARCHAR(128) NOT NULL,
  description VARCHAR(200) NOT NULL,
 
  CONSTRAINT pk_sync4j_role PRIMARY KEY (role)
);


CREATE TABLE sync4j_user_role
(
  username VARCHAR(32 ) NOT NULL,
  role     VARCHAR(128) NOT NULL,
 
  CONSTRAINT pk_sync4j_user_role PRIMARY KEY (username,role)
);


alter table sync4j_principal add constraint fk_user foreign key (
  username
)
references sync4j_user (
  username
) ON DELETE CASCADE;


alter table sync4j_principal add constraint fk_device foreign key (
  device
)
references sync4j_device (
  id
) ON DELETE CASCADE;


alter table sync4j_last_sync add constraint fk_principal foreign key (
  principal
)
references sync4j_principal (
  id
) ON DELETE CASCADE;


alter table sync4j_last_sync add constraint fk_source foreign key (
  sync_source
)
references sync4j_sync_source (
  uri
) ON DELETE CASCADE;


alter table sync4j_client_mapping add constraint fk_principal1 foreign key (
  principal
)
references sync4j_principal (
  id
) ON DELETE CASCADE;


alter table sync4j_client_mapping add constraint fk_source1 foreign key (
  sync_source
)
references sync4j_sync_source (
  uri
) ON DELETE CASCADE;

alter table sync4j_device add constraint fk_device_caps foreign key (
  id_caps
)
references sync4j_device_caps (
  id
) ON DELETE CASCADE;

create index ind_principal on sync4j_principal (username, device);
create index ind_user      on sync4j_user      (username, password);
